@@ -48,7 +48,7 @@
 /* three seconds */
 #define TIMEOUT 3
 
-int btperror(char *text);
+int btperror(char *text, int fatal=0);
 int timeout=0;
 char *progname;
 
@@ -264,10 +264,10 @@ int valsend(int fd, char *command) {
   return(EXIT_SUCCESS);
 }
 
-int rcsend(char *command)
+int rcsend(char *command, int fd)
 {
 	struct sockaddr_un addr;
-	int fd;
+	//	int fd;
 	char buffer[PACKET_SIZE+1];
         char scratch[40];
 	char remote[40];
@@ -281,31 +281,33 @@ int rcsend(char *command)
 //	progname=argv[0];
 //      progname="btp";
 
-	remote_set = 0;
-	act.sa_handler=sigalrm;
-	sigemptyset(&act.sa_mask);
-	act.sa_flags=0;           /* we need EINTR */
-	sigaction(SIGALRM,&act,NULL);
+	// Should this be run only once, too?
 
-	addr.sun_family=AF_UNIX;
-	strcpy(addr.sun_path,LIRCD);
-	fd=socket(AF_UNIX,SOCK_STREAM,0);
-	if(fd==-1)
-	{
-		btperror("Could not open\nsocket\n\nIs lircd running?");
-		// I know, but I really don't like applications just dying.
-		//		perror(progname);
-		//		exit(EXIT_FAILURE);
-		return(EXIT_FAILURE);
-	};
-	if(connect(fd,(struct sockaddr *)&addr,sizeof(addr))==-1)
-	{
-		btperror("Could not connect\nto socket\n\nIs lircd running?");
-		// Same goes here.
-		//		perror(progname);
-		//		exit(EXIT_FAILURE);
-		return(EXIT_FAILURE);
-	};
+	remote_set = 0;
+       	act.sa_handler=sigalrm;
+       	sigemptyset(&act.sa_mask);
+       	act.sa_flags=0;           /* we need EINTR */
+       	sigaction(SIGALRM,&act,NULL);
+
+	//       	addr.sun_family=AF_UNIX;
+	//	strcpy(addr.sun_path,LIRCD);
+	//	fd=socket(AF_UNIX,SOCK_STREAM,0);
+	//	if(fd==-1)
+	//	{
+	//		btperror("Could not open\nsocket\n\nIs lircd running?");
+	//		// I know, but I really don't like applications just dying.
+	//		//		perror(progname);
+	//		//		exit(EXIT_FAILURE);
+	//		return(EXIT_FAILURE);
+	//	};
+	//	if(connect(fd,(struct sockaddr *)&addr,sizeof(addr))==-1)
+	//	{
+	//		btperror("Could not connect\nto socket\n\nIs lircd running?");
+	//		// Same goes here.
+	//		//		perror(progname);
+	//		//		exit(EXIT_FAILURE);
+	//		return(EXIT_FAILURE);
+	//	};
 
 	if(!strncasecmp(command, "macro ", 6)) {
 	  //Ok... I really hate string juggling.
@@ -317,9 +319,14 @@ int rcsend(char *command)
 	    strcpy(scratch, scratchptr);
 	    if(cindex = index(scratch, ':')) {
 	      cindex[0] = 0;
-	      if(!strncasecmp(scratch, "sleep", 5)) {
+	      if(!strncasecmp(scratch, ".sleep", 6)) {
 		sleep(atoi(cindex+1));
-	      } else {
+	      } else if(!strncasecmp(scratch, ".tenths", 7)) {
+		usleep(atoi(cindex+1)*100000);
+	      } else if(!strncasecmp(scratch, ".exit", 5)) {
+		printf("%s\n", cindex+1);
+		exit(EXIT_SUCCESS); //There must be a better way.
+	      } else { //Not a command, but a remote.
 		strcpy(remote, scratch);
 		remote_set = 1;
 		sprintf(macropart,"%s %s", scratch, cindex+1);
@@ -345,6 +352,6 @@ int rcsend(char *command)
 	} else {
 	  sendstatus = valsend(fd, command);
 	}
-	close(fd);
+	//	close(fd);
 	return(sendstatus);
 }
